Crate robojackets_robocup_rtp

Crate robojackets_robocup_rtp 

rtp is a library of the cross platform messages that are sent between the base computer base station, and robots.

Re-exports

pub use control_message::ControlMessage;
pub use control_message::ControlMessageBuilder;
pub use control_message::CONTROL_MESSAGE_SIZE;
pub use robot_status_message::RobotStatusMessage;
pub use robot_status_message::RobotStatusMessageBuilder;
pub use robot_status_message::ROBOT_STATUS_SIZE;
pub use radio_addresses::BASE_STATION_ADDRESSES;
pub use radio_addresses::ROBOT_RADIO_ADDRESSES;

Modules

control_message
The Control Message is sent to robots over radio to inform them of what actions to take.
control_test_message
The control test message takes the data used by the robot for the current control step and sends the raw sensor values back to the base station.
imu_test_message
Test message sent during the IMU test
kicker_program_message
Message containing information about the current kicker programmer operation
kicker_testing
Message containing information about the kicker when running in Kicker Testing Mode
radio_addresses
The addresses of radios on the nRF24L01+ Network
radio_benchmarks
Messages related to radio benchmarking.
robot_status_message
The Robot Status Message is sent from the robots to the base station and finally to the computer

Enums

Team
The Team the Robots are on

Constants

BLUE_TEAM
Constant used to select the blue team
YELLOW_TEAM
Constant used to select the yellow team