ControlMessage

Struct ControlMessage 

pub struct ControlMessage {
    pub team: Team,
    pub robot_id: u8,
    pub shoot_mode: ShootMode,
    pub trigger_mode: TriggerMode,
    pub body_x: i16,
    pub body_y: i16,
    pub body_w: i16,
    pub dribbler_speed: i8,
    pub kick_strength: u8,
    pub role: u8,
    pub mode: Mode,
}
The Control Message is Sent from the Base Station to the Robots.

The Packed Format of this message is as follows: +———+———+———+———+———+———+———+———+ | 7 | 6 | 5 | 4 | 3 | 2 | 1 | 0 | +———+———+———+———+———+———+———+———+ | team | robot id | shoot_m | trigger_mode | +———+———+———+———+———+———+———+———+ | body_x (lsb) | +———+———+———+———+———+———+———+———+ | body_x (msb) | +———+———+———+———+———+———+———+———+ | body_y (lsb) | +———+———+———+———+———+———+———+———+ | body_y (msb) | +———+———+———+———+———+———+———+———+ | body_w (lsb) | +———+———+———+———+———+———+———+———+ | body_w (msb) | +———+———+———+———+———+———+———+———+ | dribbler_speed | +———+———+———+———+———+———+———+———+ | kick_strength | +———+———+———+———+———+———+———+———+ | role | mode | +———+———+———+———+———+———+———+———+

Size = 80 Bits = 10 Bytes

Fields

team: Team

Team of the Robot (0: Blue) (1: Yellow)

robot_id: u8

Id of the Robot

shoot_mode: ShootMode

Mode of kicking for the robot

trigger_mode: TriggerMode

Trigger Mode for the Robot (TODO: Finish Docs)

body_x: i16

X Coordinate of the Robot’s Body Frame (multiplied by VELOCITY_SCALE_FACTOR and truncated)

body_y: i16

Y Coordinate of the Robot’s Body Frame (multiplied by VELOCITY_SCALE_FACTOR and truncated)

body_w: i16

W Coordinate of the Robot’s Body Frame (multiplied by VELOCITY_SCALE_FACTOR and truncated))

dribbler_speed: i8

Speed of the dribbler (TODO: Determine Units)

kick_strength: u8

Strength of the kicker on kick (TODO: Determine Units)

role: u8

Role of This Robot (TODO: Finish Docs)

mode: Mode

The mode of the robot

Implementations

Source

impl ControlMessage

pub fn get_velocity(&self) -> Vector3<f32>

Get the velocity (x, y, w) from the control message in a vector