KickerProgramMessage

Struct KickerProgramMessage 

pub struct KickerProgramMessage {
    pub kick_on_breakbeam: bool,
    pub finished: bool,
    pub page: u32,
}
Messages sent from the robot when the kicker is being programmed

Fields

kick_on_breakbeam: bool

Is the kicker being programmed with kick on breakbeam

finished: bool

Is the kicker finished programming

page: u32

The current page being programmed