pub struct ControlTestMessage {
pub gyro_z: f32,
pub accel_x: f32,
pub accel_y: f32,
pub motor_encoders: [f32; 4],
pub delta: u32,
}Expand description
A message sent back from the robot containing all relevant sensor measurements for making control decisions.
Fields
gyro_z: f32The z-gyro value obtained from the IMU
accel_x: f32The x-accelerometer value obtained from the IMU
accel_y: f32The y-accelerometer value obtained from the IMU
motor_encoders: [f32; 4]The encoder velocities obtained from the FPGA
delta: u32The time from the last control test message to this message (us)