pub struct KickerProgramMessage {
pub kick_on_breakbeam: bool,
pub finished: bool,
pub page: u32,
}Expand description
Messages sent from the robot when the kicker is being programmed
Fields
kick_on_breakbeam: boolIs the kicker being programmed with kick on breakbeam
finished: boolIs the kicker finished programming
page: u32The current page being programmed